// 报告模块
import { get,post } from "./index";

export default {
    /**
     * 获取报告列表
     * @param Frequency
     * @param ClassifyNameFirst
     * @param ClassifyNameSecond
     * @param KeyWord
     * @param MsgIsSend
     * @param State
     * @param StartDate
     * @param EndDate
     */
    getList:params=>{
        return get('/report/list',params)
    },
    /**
     * 获取报告分类
     * @param CurrentIndex
     * @param PageSize
     * @param KeyWord
     * @param HideDayWeek 1不显示晨报/周报
     */
    getClassifyList:params=>{
        return get('/classify/list',params)
    },
    /**
     * 删除报告
     * @param ReportIds
     */
    reportDel:params=>{
        return post('/report/delete',params)
    },
    /**
     * 周报校验音频
     * @param ReportId
     */
    weekReportValidAudio:params=>{
        return get('/report/CheckDayWeekReportChapterVideo',params)
    },
    /**
     * 发布报告
     * @param ReportIds 用,隔开
     */
    reportPublish:params=>{
        return post('/report/publish',params)
    },
    /**
     * 报告取消发布
     * @param ReportIds
     * @returns 
     */
    reportPublishCancle:params=>{
        return post('/report/publish/cancle',params)
    },
    /**
     * 同时推送客群和模板消息
     * @param ReportId
     * @returns 
     */
    reportMessageSend:params=>{
        return post('/report/sendMsg',params)
    },
    /**
     * 报告详情
     * @param ReportId
     */
    getReportDetail:params=>{
        return get('/report/detail',params)
    },
    /**
     * 获取章节列表
     * @param ReportId
     */
    getChapterList:params=>{
        return get('/report/getReportChapterList',params)
    },
    /**
     * 获取章节tag
     */
    getChapterTagList:()=>{
        return get('/report/getChapterTrendTag',{})
    },
    /**
     * 编辑章节标签
     * @param ReportChapterId
     * @param Trend
     */
    editChapterTrendTag:params=>{
        return post('/report/editChapterTrendTag',params)
    },
    /**
     * 获取章节详情
     * @param ReportChapterId
     */
    getChapterDetail:params=>{
        return get('/report/getDayWeekChapter',params)
    },
    /**
     * 编辑晨报周报
     * @param ReportId
     * @param Title
     * @param ReportType
     * @param CreateTime
     * @param Author
     */
    editDayWeekReport:params=>{
        return post('/report/editDayWeekReport',params)
    },
    /**
     * 发布晨报\周报
     * @param ReportId
     */
    publishDayOrWeekReport:params=>{
        return post('/report/publishDayWeekReport',params)
    },

    // 获取研报作者列表
    reportAuthorList:params=>{
        return get('/report/author',params)
    },
    
    /**
     * 通过报告分类id获取报告内容（继承上一篇报告）
     * @param ClassifyIdFirst
     * @param ClassifyIdSecond
     */
    reportDetailByClassifyId(params){
        return get('/report/classifyIdDetail',params)
    },
    /**
     * 新增报告
     */
    reportAdd(params){
        return post('/report/add',params)
    },
    /**
     * 编辑报告
     */
    reportEdit(params){
        return post('/report/edit',params)
    },
    /**
     * 报告mark
     * @param ReportId
     * @param Status
     */
    reportMark(params){
        return post('/report/mark',params)
    },
    /**
     * 保存报告内容
     * @param ReportId
     * @param Content
     * @param NoChange 0内容没变 1内容变了
     */
    reportContentSave(params){
        return post('/report/saveReportContent',params)
    },
    /**
     * 新增晨报/周报
     * @param Title
     * @param ReportType
     * @param CreateTime
     * @param Author
     */
    dayWeekReportAdd(params){
        return post('/report/addDayWeekReport',params)
    },
    /**
     * 获取晨报/周报上一篇内容
     * @param TypeId
     * @param ReportType day晨报 week周报
     */
    chapterReportPreContent(params){
        return get('/report/getLastDayWeekReportChapter',params)
    },
    /**
     * 晨报/周报章节保存
     * 
     */
    chapterDetailSave(params){
        return post('/report/editDayWeekChapter',params)
    },
    /**
     * 判断晨报周报当前章节是否为最后一篇发布的
     * @param ReportChapterId
     */
    chapterReportIsLast(params){
        return get('/report/isLastDayWeekReportChapter',params)
    },
    /**
     * 发布晨报周报章节
     */
    chapterReportPublish(params){
        return post('/report/publishDayWeekReportChapter',params)
    },
    /**
     * 晨报数据指标列表
     * @param ReportChapterId
     */
    chapterDayReportTicketList(params){
        return get('/report/getDayReportTickerList',params)
    },
    /**
     * 定时发布报告
     * @param ReportId
     * @param PrePublishTime
     * @param PreMsgSend 定时发布成功后是否立即推送模版消息：0否，1是
     */
    reportPublishTimeSet(params){
        return post('/report/pre_publish',params)
    },

    /**
     * 中文研报提交审批
     * @param {Object} params 
     * @param {Number} params.ReportId
     * @returns 
     */
    reportCnSubmit(params){
        return post("/report/approve/submit",params)
    },
    /**
     * 中文研报撤销审批
     * @param {Object} params 
     * @param {Number} params.ReportId
     * @returns 
     */
    reportCnCancel(params){
        return post("/report/approve/cancel",params)
    },
    /**
     * 研报转pdf、长图
     * @param {Object} params 
     * @param {Number} params.ReportId
     * @returns 
     */
    report2PdfImg(params){
        return post("/smart_report/get_pdf_url",params)
    },

     // 资源库列表
    imgReourceList:params=>{
        return get('/smart_report/resource/list',params)
    },

    //音频上传
    uploadAudio: params => {
        return post('/voice/upload',params)
    },

        
    /* v2=============================== */
    /**
     * 获取分类关联品种
     * @param {*} params 
     * @returns 
     */
    classifyPermissionList: params => {
        return get('/classify/permission_list',params)
    },

    /**
     * 获取系统用户
     * @param {*} params 
     * @returns 
     */
    getSystemUser: params => {
        return get("/system/department/user_tree",params)
    },

    /**
     * 获取有权限的列表 
     * @param {
     *  CurrentIndex PageSize KeyWord ClassifyIdFirst ClassifyIdSecond ClassifyIdThird
    * } params 
    * @returns 
    */
    getAuthReportList: params => {
        return get('/report/list/authorized',params)
    },
 
    /**
    * 报告基础信息
    * @param {*ReportId} params 
    * @returns 
    */
    getRportBase: params => {
        return get('/report/detail/base',params)
    },
 
    /**
    * 修改章节基础信息
    * @param {*} params 
    * @returns 
    */
    editChapterBase: params => {
        return post('/report/chapter/base_info/edit',params)
    },
 
    /**
    * 章节拖动排序
    * @param {*ReportChapterId PrevReportChapterId NextReportChapterId} params 
    * @returns 
    */
    moveChapter: params => {
        return post('/report/chapter/move',params)
    },
 
    /**
     * 删除章节
     * @param {*ReportChapterId} params 
     * @returns 
     */
    removeChapter: params => {
        return post('/report/chapter/del',params)
    },
 
    /**
     * 添加章节
     * 
     * @param {* Title  ReportId PermissionIdList AdminIdList} params 
     * @returns 
     */
    addChapter: params => {
        return post('/report/chapter/add',params)
    },
 
    /**
     * 上传章节音频
     * @param {*ReportChapterId File} params 
     * @returns 
     */
    uploadChpterAudio: params => {
        return post('/report/chapter/voice/upload',params)
    },
 
    /**
     * 校验所有章节是否发布
     * @param {*ReportId} params 
     * @returns 
     */
    checkChaterPublishState: params => {
        return get('/report/chapter/un_publish/list',params)
    },
 
    /**
     * 设置版图
     * @param {*ReportId HeadImg HeadResourceId EndImg EndResourceId CanvasColor} params 
     * @returns 
     */
    setReportLayoutImg: params => {
        return post('/report/layout_img/edit',params)
    },
 
    /**
     * 获取分类关联的品种列表
     * @param {*ClassifyId} params 
     * @returns 
     */
    getClassifyPermissionList: params => {
        return	get('/classify/permission/list',params)
    },

    /**
     * 保存章节标题 
     * @param {*ReportChapterId Title} params 
     * @returns 
     */
    saveChapterTitle: params => {
        return post('/report/chapter/title/edit',params)
    },

    /**
     * 获取报告图表刷新状态
     * @param {*} params 
     * @returns 
     */
    getChartRefreshStatus: params => {
        return post('/datamanage/chart_info/batch_refresh/result',params)
    },

    /**
     * 图表刷新
     * @param {*} params 
     *  ChartInfoCode: code_arr,
        PrimarSource: 'report',
        PrimaryId: id,
        SubId: chapterId
     * @returns 
     */
    reportChartRefresh: params => {
        return post('/datamanage/chart_info/batch_refresh',params)
    },

    /**
     * 获取报告表格刷新状态
     * @param {*} params 
     * @returns 
     */
    getSheetRefreshResult: params => {
        return post('/datamanage/excel_info/table/batch_refresh/result',params)
    },

    /**
     * 表格刷新
     * @param {*} params 
     * ExcelCodes: sheet_code_arr,
        Source: 'report',
        PrimaryId: id,
        SubId: chapterId
     * @returns 
     */
    reportSheetRefresh: params => {
        return post('/datamanage/excel_info/table/batch_refresh',params) 
    }

}
